@@ -5,9 +5,7 @@ from cpm.api.result import OK
 from cpm.api.result import FAIL
 from cpm.domain.creation_service import CreationService
 from cpm.domain.creation_service import CreationOptions
-from cpm.domain.project_loader import ProjectLoader
-from cpm.infrastructure.filesystem import Filesystem
-from cpm.infrastructure.yaml_handler import YamlHandler
+from cpm.domain.project.project_loader import ProjectLoader
 
 
 def new_project(creation_service, options=CreationOptions()):
@@ -19,15 +17,13 @@ def new_project(creation_service, options=CreationOptions()):
 
 
 def execute(argv):
-    create_parser = argparse.ArgumentParser(prog='cpm create', description='Chromos Package Manager', add_help=False)
+    create_parser = argparse.ArgumentParser(prog='cpm create', description='Create a new cpm project', add_help=False)
     create_parser.add_argument('project_name')
     create_parser.add_argument('-s', '--no-sample-code', required=False, action='store_true', default=False)
     args = create_parser.parse_args(argv)
 
-    filesystem = Filesystem()
-    yaml_handler = YamlHandler(filesystem)
-    project_loader = ProjectLoader(yaml_handler, filesystem)
-    service = CreationService(filesystem, project_loader)
+    project_loader = ProjectLoader()
+    service = CreationService(project_loader)
 
     options = CreationOptions(
         generate_sample_code=not args.no_sample_code,
