@@ -20,6 +20,8 @@ def compose_target(target_name, project_descriptor):
     target.cflags = project_descriptor.build.cflags + target_description.build.cflags
     target.ldflags = project_descriptor.build.ldflags + target_description.build.ldflags
     target.libraries = project_descriptor.build.libraries + target_description.build.libraries
+    target.include_directories.update(project_descriptor.build.includes)
+    target.main = target_description.main
     target.image = target_description.image
     target.dockerfile = target_description.dockerfile
     target.post_build = target_description.post_build
@@ -35,6 +37,7 @@ def compose_tests(target_name, project_descriptor, project):
     project.test.cflags = project_descriptor.test.cflags + target_description.test.cflags
     project.test.ldflags = project_descriptor.test.ldflags + target_description.test.ldflags
     project.test.libraries = project_descriptor.test.libraries + target_description.test.libraries
+    project.test.include_directories.update(project_descriptor.test.includes)
     compose_packages(project_descriptor.test.packages, project.test)
     compose_packages(target_description.test.packages, project.test)
 
